@@ -70,9 +70,6 @@ class mateMenuConfig( object ):
         self.builder.get_object("label11").set_text(_("Border width:"))
         self.builder.get_object("label25").set_text(_("pixels"))
 
-        self.builder.get_object("label8").set_text(_("Opacity:"))
-        self.builder.get_object("label9").set_text("%")
-
         self.builder.get_object("buttonTextLabel").set_text(_("Button text:"))
         self.builder.get_object("label1").set_text(_("Options"))
         self.builder.get_object("applicationsLabel").set_text(_("Applications"))
@@ -82,6 +79,13 @@ class mateMenuConfig( object ):
         self.builder.get_object("mainbuttonLabel").set_text(_("Main button"))
         self.builder.get_object("pluginsLabel").set_text(_("Plugins"))
 
+        self.builder.get_object("searchEngineTitleLabel").set_text(_("Search Engines:"))
+        self.builder.get_object("enable_ddg").set_label(_("DuckDuckGo"))
+        self.builder.get_object("enable_google").set_label(_("Google"))
+        self.builder.get_object("enable_wikipedia").set_label(_("Wikipedia"))
+        self.builder.get_object("enable_dictionary").set_label(_("Dictionary"))
+        self.builder.get_object("enable_computer").set_label(_("Computer"))
+
         self.builder.get_object("backgroundColorLabel").set_text(_("Background:"))
         self.builder.get_object("headingColorLabel").set_text(_("Headings:"))
         self.builder.get_object("borderColorLabel").set_text(_("Borders:"))
@@ -136,13 +140,17 @@ class mateMenuConfig( object ):
         self.hover = self.builder.get_object( "hover" )
         self.hoverDelay = self.builder.get_object( "hoverDelay" )
         self.rememberFilter = self.builder.get_object( "remember_filter" )
+        self.enableDdg = self.builder.get_object( "enable_ddg" )
+        self.enableGoogle = self.builder.get_object( "enable_google" )
+        self.enableWikipedia = self.builder.get_object( "enable_wikipedia" )
+        self.enableDictionary = self.builder.get_object( "enable_dictionary" )
+        self.enableComputer = self.builder.get_object( "enable_computer" )
         self.iconSize = self.builder.get_object( "iconSize" )
         self.favIconSize = self.builder.get_object( "favIconSize" )
         self.placesIconSize = self.builder.get_object( "placesIconSize" )
         self.systemIconSize = self.builder.get_object( "systemIconSize" )
         self.favCols = self.builder.get_object( "numFavCols" )
         self.borderWidth = self.builder.get_object( "borderWidth" )
-        self.opacity = self.builder.get_object( "opacity" )
         self.useCustomColors = self.builder.get_object( "useCustomColors" )
         self.backgroundColor = self.builder.get_object( "backgroundColor" )
         self.borderColor = self.builder.get_object( "borderColor" )
@@ -214,11 +222,16 @@ class mateMenuConfig( object ):
         self.bindGSettingsValueToWidget( self.settingsApplications, "int", "fav-cols", self.favCols, "value-changed", self.favCols.set_value, self.favCols.get_value )
         self.bindGSettingsValueToWidget( self.settingsApplications, "bool", "remember-filter", self.rememberFilter, "toggled", self.rememberFilter.set_active, self.rememberFilter.get_active)
 
+        self.bindGSettingsValueToWidget( self.settingsApplications, "bool", "enable-ddg", self.enableDdg, "toggled", self.enableDdg.set_active, self.enableDdg.get_active)
+        self.bindGSettingsValueToWidget( self.settingsApplications, "bool", "enable-google", self.enableGoogle, "toggled", self.enableGoogle.set_active, self.enableGoogle.get_active)
+        self.bindGSettingsValueToWidget( self.settingsApplications, "bool", "enable-wikipedia", self.enableWikipedia, "toggled", self.enableWikipedia.set_active, self.enableWikipedia.get_active)
+        self.bindGSettingsValueToWidget( self.settingsApplications, "bool", "enable-dictionary", self.enableDictionary, "toggled", self.enableDictionary.set_active, self.enableDictionary.get_active)
+        self.bindGSettingsValueToWidget( self.settingsApplications, "bool", "enable-computer", self.enableComputer, "toggled", self.enableComputer.set_active, self.enableComputer.get_active)
+
         self.bindGSettingsValueToWidget( self.settingsPlaces, "int", "icon-size", self.placesIconSize, "value-changed", self.placesIconSize.set_value, self.placesIconSize.get_value )
         self.bindGSettingsValueToWidget( self.settingsSystem, "int", "icon-size", self.systemIconSize, "value-changed", self.systemIconSize.set_value, self.systemIconSize.get_value )
 
         self.bindGSettingsValueToWidget( self.settings, "int", "border-width", self.borderWidth, "value-changed", self.borderWidth.set_value, self.borderWidth.get_value_as_int )
-        self.bindGSettingsValueToWidget( self.settings, "int", "opacity", self.opacity, "value-changed", self.opacity.set_value, self.opacity.get_value_as_int )
         self.bindGSettingsValueToWidget( self.settings, "bool", "use-custom-color", self.useCustomColors, "toggled", self.useCustomColors.set_active, self.useCustomColors.get_active )
         self.bindGSettingsValueToWidget( self.settings, "color", "custom-color", self.backgroundColor, "color-set", self.backgroundColor.set_rgba, self.getBackgroundColor )
         self.bindGSettingsValueToWidget( self.settings, "color", "custom-heading-color", self.headingColor, "color-set", self.headingColor.set_rgba, self.getHeadingColor )
