@@ -19,22 +19,21 @@
 # Free Software Foundation, Inc.,
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
-__VERSION__='17.04.3'
+__VERSION__='17.10.5'
 
 import gc
 import gi
 import gettext
 import os
-import platform
 import subprocess
 import sys
 import traceback
 import signal
+import setproctitle
 
 gi.require_version("Gtk", "3.0")
 gi.require_version('MatePanelApplet', '4.0')
 
-from ctypes import *
 from gi.repository import Gtk, GdkPixbuf, Gdk, GObject
 from gi.repository import MatePanelApplet
 from gi.repository import Gio
@@ -45,24 +44,12 @@ try:
     import mate_menu.pointerMonitor as pointerMonitor
 except Exception, e:
     print e
-    sys.exit( 1 )
+    sys.exit(1)
 
 signal.signal(signal.SIGINT, signal.SIG_DFL)
-GObject.threads_init()
 
 # Rename the process
-architecture = platform.uname()[4]
-if architecture in 'x86_64':
-    libc = CDLL('libc.so.6')
-    libc.prctl(15, 'mate-menu', 0, 0, 0)
-else:
-    import dl
-    if os.path.exists('/lib/libc.so.6'):
-        libc = dl.open('/lib/libc.so.6')
-        libc.call('prctl', 15, 'mate-menu', 0, 0, 0)
-    elif os.path.exists('/lib/i386-linux-gnu/libc.so.6'):
-        libc = dl.open('/lib/i386-linux-gnu/libc.so.6')
-        libc.call('prctl', 15, 'mate-menu', 0, 0, 0)
+setproctitle.setproctitle('mate-menu')
 
 # i18n
 gettext.install("mate-menu", "/usr/share/locale")
@@ -76,10 +63,9 @@ from mate_menu.execute import *
 class MainWindow( object ):
     """This is the main class for the application"""
 
-    def __init__( self, toggleButton, settings, keybinder ):
+    def __init__(self, toggleButton, settings):
 
         self.settings = settings
-        self.keybinder = keybinder
         self.data_path = os.path.join( '/', 'usr', 'share', 'mate-menu' )
         self.icon = "/usr/share/mate-menu/icons/mate-logo.svg"
 
@@ -88,9 +74,6 @@ class MainWindow( object ):
         builder = Gtk.Builder()
         builder.add_from_file(os.path.join( self.data_path, "mate-menu.glade" ))
         self.window     = builder.get_object( "mainWindow" )
-        self.window.realize()
-        self.window.get_window().set_decorations(Gdk.WMDecoration.BORDER)
-        self.window.set_title('')
         self.paneholder = builder.get_object( "paneholder" )
         self.border     = builder.get_object( "border" )
 
@@ -99,9 +82,15 @@ class MainWindow( object ):
         self.panesToColor = [ ]
         self.headingsToColor = [ ]
 
-        self.window.connect( "key-press-event", self.onKeyPress )
-        self.window.connect( "focus-in-event", self.onFocusIn )
-        self.loseFocusId = self.window.connect( "focus-out-event", self.onFocusOut )
+        self.window.realize()
+        self.window.get_window().set_decorations(Gdk.WMDecoration.BORDER)
+        self.window.set_title('')
+        self.window.set_app_paintable(True)
+
+        self.window.connect("draw", self.onWindowDraw)
+        self.window.connect("key-press-event", self.onWindowKeyPress)
+        self.window.connect("focus-in-event", self.onWindowFocusIn)
+        self.loseFocusId = self.window.connect("focus-out-event", self.onWindowFocusOut)
         self.loseFocusBlocked = False
 
         self.window.stick()
@@ -120,7 +109,6 @@ class MainWindow( object ):
         self.settings.connect( "changed::custom-heading-color", self.toggleCustomHeadingColor )
         self.settings.connect( "changed::custom-color", self.toggleCustomBackgroundColor )
         self.settings.connect( "changed::border-width", self.toggleBorderWidth )
-        self.settings.connect( "changed::opacity", self.toggleOpacity )
 
         self.getSetGSettingEntries()
 
@@ -161,10 +149,6 @@ class MainWindow( object ):
         self.borderwidth = settings.get_int(key)
         self.SetupMateMenuBorder()
 
-    def toggleOpacity( self, settings, key, args = None ):
-        self.opacity = settings.get_int(key)
-        self.SetupMateMenuOpacity()
-
     def toggleUseCustomColor( self, settings, key, args = None ):
         self.usecustomcolor = settings.get_boolean(key)
         self.loadTheme()
@@ -188,30 +172,12 @@ class MainWindow( object ):
         self.customheadingcolor   = self.settings.get_string( "custom-heading-color" )
         self.custombordercolor    = self.settings.get_string( "custom-border-color" )
         self.borderwidth          = self.settings.get_int( "border-width" )
-        self.opacity              = self.settings.get_int( "opacity" )
         self.offset               = self.settings.get_int( "offset" )
         self.enableTooltips       = self.settings.get_boolean( "tooltips-enabled" )
         self.startWithFavorites   = self.settings.get_boolean( "start-with-favorites" )
 
         self.globalEnableTooltips = self.panelSettings.get_boolean( "tooltips-enabled" )
 
-    def SetupMateMenuBorder( self, color = None ):
-        context = self.window.get_style_context()
-        if self.usecustomcolor:
-            borderColor = Gdk.RGBA()
-            borderColor.parse( self.custombordercolor )
-            self.window.override_background_color( context.get_state(), borderColor )
-        elif color is not None:
-            self.window.override_background_color( context.get_state(), color )
-        self.border.set_padding( self.borderwidth, self.borderwidth, self.borderwidth, self.borderwidth )
-
-    def SetupMateMenuOpacity( self ):
-        print "Opacity is: " + str(self.opacity)
-        opacity = float(self.opacity) / float(100)
-        print "Setting opacity to: " + str(opacity)
-        if opacity is not 1:
-            self.window.set_opacity(opacity)
-
     def PopulatePlugins( self ):
         self.panesToColor = [ ]
         self.headingsToColor = [ ]
@@ -280,26 +246,24 @@ class MainWindow( object ):
                 VBox1 = Gtk.Box( orientation=Gtk.Orientation.VERTICAL )
                 if MyPlugin.heading != "":
                     Label1 = Gtk.Label(label= MyPlugin.heading )
-                    Align1 = Gtk.Alignment.new( 0, 0, 0, 0 )
-                    Align1.set_padding( 10, 5, 10, 0 )
-                    Align1.add( Label1 )
+                    Label1.set_margin_start(10)
                     self.headingsToColor.append( Label1 )
-                    Align1.show()
                     Label1.show()
 
                     if not hasattr( MyPlugin, 'sticky' ) or MyPlugin.sticky == True:
                         heading = Gtk.EventBox()
-                        Align1.set_padding( 0, 0, 10, 0 )
                         heading.set_visible_window( False )
                         heading.set_size_request( MyPlugin.width, 30 )
                     else:
                         heading = Gtk.Box( orientation=Gtk.Orientation.HORIZONTAL )
+                        Label1.set_margin_top(10)
+                        Label1.set_margin_bottom(5)
                         #heading.set_relief( Gtk.ReliefStyle.NONE )
                         heading.set_size_request( MyPlugin.width, -1 )
                         #heading.set_sensitive(False)
                         #heading.connect( "button_press_event", self.TogglePluginView, VBox1, MyPlugin.icon, MyPlugin.heading, MyPlugin )
 
-                    heading.add( Align1 )
+                    heading.add(Label1)
                     heading.show()
                     VBox1.pack_start( heading, False, False, 0 )
                 VBox1.show()
@@ -350,13 +314,11 @@ class MainWindow( object ):
                 if self.plugins and hasattr( MyPlugin, 'hideseparator' ) and not MyPlugin.hideseparator:
                     Image1 = Gtk.Image()
                     Image1.set_from_pixbuf( seperatorImage )
+                    Image1.set_margin_start(6)
+                    Image1.set_margin_end(6)
                     Image1.show()
-                    #ImageBox.add( Image1 )
 
-                    Align1 = Gtk.Alignment.new(0, 0, 0, 0)
-                    Align1.set_padding( 0, 0, 6, 6 )
-                    Align1.add(Image1)
-                    ImageBox.add(Align1)
+                    ImageBox.add(Image1)
                     ImageBox.show_all()
 
 
@@ -382,10 +344,21 @@ class MainWindow( object ):
 
     def loadTheme( self ):
         colors = self.getDefaultColors()
-        self.SetPaneColors( self.panesToColor, colors["bg"] )
-        self.SetupMateMenuBorder( colors["border"] )
+        self.SetupMateMenuBorder()
+        self.SetPaneColors(self.panesToColor, colors["bg"])
         self.SetHeadingStyle( self.headingsToColor )
 
+    def SetupMateMenuBorder(self):
+        style = self.window.get_style_context()
+        styleProvider = Gtk.CssProvider()
+        styleProvider.load_from_data(".background { border-width: %dpt; }" % self.borderwidth)
+        style.add_provider(styleProvider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
+
+        self.border.set_margin_top(self.borderwidth)
+        self.border.set_margin_bottom(self.borderwidth)
+        self.border.set_margin_start(self.borderwidth)
+        self.border.set_margin_end(self.borderwidth)
+
     def SetPaneColors( self, items, color = None ):
         for item in items:
             context = item.get_style_context()
@@ -420,8 +393,7 @@ class MainWindow( object ):
         widget.set_tooltip_text( tip )
 
     def RegenPlugins( self, *args, **kargs ):
-        #print
-        #print u"Reloading Plugins..."
+        #print("Reloading Plugins...")
         for item in self.paneholder:
             item.destroy()
 
@@ -445,9 +417,22 @@ class MainWindow( object ):
         self.PopulatePlugins()
         self.loadTheme()
 
-        #print NAME+u" reloaded"
+        #print(NAME + " reloaded")
 
-    def onKeyPress( self, widget, event ):
+    def onWindowDraw(self, widget, cr):
+        if self.usecustomcolor:
+            borderColor = Gdk.RGBA()
+            borderColor.parse(self.custombordercolor)
+            Gdk.cairo_set_source_rgba(cr, borderColor)
+            cr.paint()
+        else:
+            style = widget.get_style_context()
+            req = widget.get_preferred_size()[0]
+            Gtk.render_background(style, cr, 0, 0, req.width, req.height)
+            Gtk.render_frame(style, cr, 0, 0, req.width, req.height)
+        return False
+
+    def onWindowKeyPress( self, widget, event ):
         if event.keyval == Gdk.KEY_Escape:
             self.hide()
             return True
@@ -459,7 +444,7 @@ class MainWindow( object ):
         # Hack for opacity not showing on first composited draw
         if self.firstTime:
             self.firstTime = False
-            self.SetupMateMenuOpacity()
+            self.window.set_opacity(1.0)
 
         self.window.get_window().focus( Gdk.CURRENT_TIME )
 
@@ -479,14 +464,14 @@ class MainWindow( object ):
 
         self.window.hide()
 
-    def onFocusIn( self, *args ):
+    def onWindowFocusIn(self, *args):
         if self.loseFocusBlocked:
             self.window.handler_unblock( self.loseFocusId )
             self.loseFocusBlocked = False
 
         return False
 
-    def onFocusOut( self, *args):
+    def onWindowFocusOut(self, *args):
         if self.window.get_visible():
             self.hide()
         return False
@@ -501,30 +486,28 @@ class MenuWin( object ):
         self.data_path = os.path.join('/','usr','share','mate-menu')
         self.applet = applet
         self.settings = Gio.Settings.new("org.mate.mate-menu")
-        self.keybinder = keybinding.GlobalKeyBinding()
+        self.loadSettings()
+
+        self.createPanelButton()
+
+        self.mate_settings = Gio.Settings.new("org.mate.interface")
+        self.mate_settings.connect( "changed::gtk-theme", self.changeTheme )
+
         self.settings.connect( "changed::applet-text", self.reloadSettings )
         self.settings.connect( "changed::theme-name", self.changeTheme )
         self.settings.connect( "changed::hot-key", self.reloadSettings )
         self.settings.connect( "changed::applet-icon", self.reloadSettings )
         self.settings.connect( "changed::hide-applet-icon", self.reloadSettings )
         self.settings.connect( "changed::applet-icon-size", self.reloadSettings )
-        self.settings.connect( "changed::hot-key", self.hotkeyChanged )
-        self.loadSettings()
-
-        self.mate_settings = Gio.Settings.new("org.mate.interface")
-        self.mate_settings.connect( "changed::gtk-theme", self.changeTheme )
-
-        self.createPanelButton()
 
         self.applet.set_flags( MatePanelApplet.AppletFlags.EXPAND_MINOR )
         self.applet.connect( "button-press-event", self.showMenu )
         self.applet.connect( "change-orient", self.changeOrientation )
         self.applet.connect("enter-notify-event", self.enter_notify)
         self.applet.connect("leave-notify-event", self.leave_notify)
-        self.mainwin = MainWindow( self.button_box, self.settings, self.keybinder )
+        self.mainwin = MainWindow(self.button_box, self.settings)
         self.mainwin.window.connect( "map-event", self.onWindowMap )
         self.mainwin.window.connect( "unmap-event", self.onWindowUnmap )
-        self.mainwin.window.connect( "realize", self.onRealize )
         self.mainwin.window.connect( "size-allocate", lambda *args: self.positionMenu() )
 
         self.mainwin.window.set_name("mate-menu") # Name used in Gtk RC files
@@ -534,20 +517,39 @@ class MenuWin( object ):
         if self.mainwin.icon:
             Gtk.Window.set_default_icon_name( self.mainwin.icon )
 
-        self.bind_hot_key()
-        self.applet.set_can_focus(False)
+        try:
+            self.keybinder = keybinding.GlobalKeyBinding()
+            if self.hotkeyText != "":
+                self.keybinder.grab( self.hotkeyText )
+            self.keybinder.connect("activate", self.onBindingPress)
+            self.keybinder.start()
+            self.settings.connect( "changed::hot-key", self.hotkeyChanged )
+            print "Binding to Hot Key: " + self.hotkeyText
+        except Exception, cause:
+            self.keybinder = None
+            print "** WARNING ** - Keybinder Error"
+            print "Error Report :\n", str(cause)
 
-        self.pointerMonitor = pointerMonitor.PointerMonitor()
-        self.pointerMonitor.connect("activate", self.onPointerOutside)
+        self.applet.set_can_focus(False)
+        
+        try:
+            self.pointerMonitor = pointerMonitor.PointerMonitor()
+            self.pointerMonitor.connect("activate", self.onPointerOutside)
+            self.mainwin.window.connect( "realize", self.onRealize )
+        except Exception, cause:
+            print "** WARNING ** - Pointer Monitor Error"
+            print "Error Report :\n", str(cause)
 
     def onWindowMap( self, *args ):
         self.applet.get_style_context().set_state( Gtk.StateFlags.SELECTED )
-        self.keybinder.set_focus_window( self.mainwin.window.get_window() )
+        if self.keybinder is not None:
+            self.keybinder.set_focus_window(self.mainwin.window.get_window())
         return False
 
     def onWindowUnmap( self, *args ):
         self.applet.get_style_context().set_state( Gtk.StateFlags.NORMAL )
-        self.keybinder.set_focus_window()
+        if self.keybinder is not None:
+            self.keybinder.set_focus_window()
         return False
 
     def onRealize( self, *args):
@@ -598,23 +600,25 @@ class MenuWin( object ):
             pass
 
         if self.applet.get_orient() == MatePanelApplet.AppletOrient.UP or self.applet.get_orient() == MatePanelApplet.AppletOrient.DOWN:
-            self.button_box = Gtk.Box( orientation=Gtk.Orientation.HORIZONTAL )
-            self.button_box.pack_start( self.button_icon, False, False, 0 )
-            self.button_box.pack_start( self.systemlabel, False, False, 0 )
-            self.button_icon.set_padding( 5, 0 )
+            self.button_box = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
+            self.button_box.pack_start(self.button_icon, False, False, 0)
+            self.button_box.pack_start(self.systemlabel, False, False, 0)
+            self.button_icon.set_margin_start(5)
+            self.button_icon.set_margin_end(5)
         # if we have a vertical panel
         elif self.applet.get_orient() == MatePanelApplet.AppletOrient.LEFT:
-            self.button_box = Gtk.Box( orientation=Gtk.Orientation.VERTICAL )
-            self.systemlabel.set_angle( 270 )
-            self.button_box.pack_start( self.button_icon , False, False, 0)
-            self.button_box.pack_start( self.systemlabel , False, False, 0)
-            self.button_icon.set_padding( 0, 5 )
-        elif self.applet.get_orient( orientation=Gtk.Orientation.VERTICAL ) == MatePanelApplet.AppletOrient.RIGHT:
-            self.button_box = Gtk.Box()
-            self.systemlabel.set_angle( 90 )
-            self.button_box.pack_start( self.systemlabel , False, False, 0)
-            self.button_box.pack_start( self.button_icon , False, False, 0)
-            self.button_icon.set_padding( 0, 5 )
+            self.button_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+            self.systemlabel.set_angle(270)
+            self.button_box.pack_start(self.button_icon , False, False, 0)
+            self.button_box.pack_start(self.systemlabel , False, False, 0)
+            self.button_icon.set_padding(0, 5)
+        elif self.applet.get_orient() == MatePanelApplet.AppletOrient.RIGHT:
+            self.button_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+            self.systemlabel.set_angle(90)
+            self.button_box.pack_start(self.button_icon , False, False, 0)
+            self.button_box.pack_start(self.systemlabel , False, False, 0)
+            self.button_icon.set_margin_top(5)
+            self.button_icon.set_margin_bottom(5)
 
         self.button_box.set_homogeneous( False )
         self.button_box.show_all()
@@ -629,6 +633,8 @@ class MenuWin( object ):
         self.buttonText =  self.settings.get_string( "applet-text" )
         self.theme_name =  self.settings.get_string( "theme-name" )
         self.hotkeyText =  self.settings.get_string( "hot-key" )
+        if not os.path.exists(self.settings.get_string("applet-icon")):
+            self.settings.reset("applet-icon")
         self.buttonIcon =  self.settings.get_string( "applet-icon" )
         self.iconSize = self.settings.get_int( "applet-icon-size" )
 
@@ -688,20 +694,6 @@ class MenuWin( object ):
         self.do_image(self.buttonIcon, False)
         self.sizeButton()
 
-    def bind_hot_key (self):
-        try:
-            if self.hotkeyText != "":
-                self.keybinder.grab( self.hotkeyText )
-            self.keybinder.connect("activate", self.onBindingPress)
-            self.keybinder.start()
-            # Binding menu to hotkey
-            print "Binding to Hot Key: " + self.hotkeyText
-
-        except Exception, cause:
-            print "** WARNING ** - Menu Hotkey Binding Error"
-            print "Error Report :\n", str(cause)
-            pass
-
     def hotkeyChanged (self, schema, key):
         self.hotkeyText =  self.settings.get_string( "hot-key" )
         self.keybinder.rebind(self.hotkeyText)
@@ -711,10 +703,10 @@ class MenuWin( object ):
             self.button_icon.hide()
         else:
             self.button_icon.show()
-     #   This code calculates width and height for the button_box
-     #   and takes the orientation in account
-        bi_req = self.button_icon.size_request()
-        sl_req = self.systemlabel.size_request()
+        # This code calculates width and height for the button_box
+        # and takes the orientation in account
+        bi_req = self.button_icon.get_preferred_size()[1]
+        sl_req = self.systemlabel.get_preferred_size()[1]
         if self.applet.get_orient() == MatePanelApplet.AppletOrient.UP or self.applet.get_orient() == MatePanelApplet.AppletOrient.DOWN:
             if self.hideIcon:
                 self.applet.set_size_request( sl_req.width + 2, bi_req.height )
@@ -743,9 +735,16 @@ class MenuWin( object ):
         Execute( os.path.join( "/", "usr", "lib", "mate-menu", "mate-menu-config.py" ) )
 
     def showMenuEditor( self, action, userdata = None ):
-        try:
+        def pathExists(filename):
+            if os.path.exists(filename):
+                return True
+            for path in os.environ["PATH"].split(os.pathsep):
+                if os.path.exists(os.path.join(path, filename)):
+                    return True
+
+        if pathExists("menulibre"):
             Execute("menulibre")
-        except:
+        elif pathExists("mozo"):
             Execute("mozo")
 
     def showMenu( self, widget=None, event=None ):
@@ -775,37 +774,49 @@ class MenuWin( object ):
         ourHeight = self.mainwin.window.get_size()[1] + self.mainwin.offset
 
         # Get the dimensions/position of the widgetToAlignWith
-        entryX = self.applet.get_window().get_origin().x
-        entryY = self.applet.get_window().get_origin().y
+        try:
+            entryX = self.applet.get_window().get_origin().x
+            entryY = self.applet.get_window().get_origin().y
+        except AttributeError:
+            # In older Gtk3 get_origin returns an unnamed tuple so the code above fails
+            entryX = self.applet.get_window().get_origin()[1]
+            entryY = self.applet.get_window().get_origin()[2]
 
         entryWidth, entryHeight =  self.applet.get_allocation().width, self.applet.get_allocation().height
         entryHeight = entryHeight + self.mainwin.offset
 
-        # Get the screen dimensions
-        screenHeight = Gdk.Screen.height()
-        screenWidth = Gdk.Screen.width()
+        # Get the monitor dimensions
+        display = self.applet.get_display()
+        if (Gtk.MAJOR_VERSION, Gtk.MINOR_VERSION) >= (3, 22):
+            monitor = display.get_monitor_at_window(self.applet.get_window())
+            monitorGeometry = monitor.get_geometry()
+        else:
+            screen = display.get_default_screen()
+            monitor = screen.get_monitor_at_window(self.applet.get_window())
+            monitorGeometry = screen.get_monitor_geometry(monitor)
+
         if self.applet.get_orient() == MatePanelApplet.AppletOrient.UP or self.applet.get_orient() == MatePanelApplet.AppletOrient.DOWN:
-            if entryX + ourWidth < screenWidth or  entryX + entryWidth / 2 < screenWidth / 2:
+            if entryX + ourWidth < monitorGeometry.width or entryX + entryWidth / 2 < monitorGeometry.width / 2:
             # Align to the left of the entry
                 newX = entryX
             else:
                 # Align to the right of the entry
                 newX = entryX + entryWidth - ourWidth
 
-            if entryY + entryHeight / 2 < screenHeight / 2:
+            if entryY + entryHeight / 2 < monitorGeometry.height / 2:
                 # Align to the bottom of the entry
                 newY = entryY + entryHeight
             else:
                 newY = entryY - ourHeight
         else:
-            if entryX + entryWidth / 2 < screenWidth / 2:
+            if entryX + entryWidth / 2 < monitorGeometry.width / 2:
                 # Align to the left of the entry
                 newX = entryX + entryWidth
             else:
                 # Align to the right of the entry
                 newX = entryX - ourWidth
 
-            if entryY + ourHeight < screenHeight or entryY + entryHeight / 2 < screenHeight / 2:
+            if entryY + ourHeight < monitorGeometry.height or entryY + entryHeight / 2 < monitorGeometry.height / 2:
                 # Align to the bottom of the entry
                 newY = entryY
             else:
@@ -816,16 +827,16 @@ class MenuWin( object ):
     # this callback is to create a context menu
     def create_menu(self):
         action_group = Gtk.ActionGroup(name="context-menu")
-        action = Gtk.Action(name="MateMenuPrefs", label=_("Preferences"), tooltip=None, stock_id="gtk-preferences")
+        action = Gtk.Action(name="MateMenuPrefs", label=_("Preferences"), tooltip=None, icon_name="preferences-system")
         action.connect("activate", self.showPreferences)
         action_group.add_action(action)
-        action = Gtk.Action(name="MateMenuEdit", label=_("Edit menu"), tooltip=None, stock_id="gtk-edit")
+        action = Gtk.Action(name="MateMenuEdit", label=_("Edit menu"), tooltip=None, stock_id=Gtk.STOCK_EDIT)
         action.connect("activate", self.showMenuEditor)
         action_group.add_action(action)
-        action = Gtk.Action(name="MateMenuReload", label=_("Reload plugins"), tooltip=None, stock_id="gtk-refresh")
+        action = Gtk.Action(name="MateMenuReload", label=_("Reload plugins"), tooltip=None, icon_name="view-refresh")
         action.connect("activate", self.mainwin.RegenPlugins)
         action_group.add_action(action)
-        action = Gtk.Action(name="MateMenuAbout", label=_("About"), tooltip=None, stock_id="gtk-about")
+        action = Gtk.Action(name="MateMenuAbout", label=_("About"), tooltip=None, icon_name="help-about")
         action.connect("activate", self.showAboutDialog)
         action_group.add_action(action)
         action_group.set_translation_domain ("mate-menu")
