@@ -142,8 +142,9 @@ class easyButton( Gtk.Button ):
         self.set_relief( Gtk.ReliefStyle.NONE )
         self.set_size_request( buttonWidth, buttonHeight )
 
-        Align1 = Gtk.Alignment.new( 0, 0.5, 1.0, 0 )
         HBox1 = Gtk.Box( orientation=Gtk.Orientation.HORIZONTAL )
+        HBox1.set_valign(Gtk.Align.CENTER)
+        HBox1.set_hexpand(True)
         self.labelBox = Gtk.Box( orientation=Gtk.Orientation.VERTICAL, spacing=2 )
 
 
@@ -169,10 +170,10 @@ class easyButton( Gtk.Button ):
         self.labelBox.show()
         HBox1.pack_start( self.labelBox , True, True, 0)
         HBox1.show()
-        Align1.add( HBox1 )
-        Align1.show()
-        self.add( Align1 )
+        self.add( HBox1 )
 
+        self.connectSelf( "focus-in-event", self.onFocusIn )
+        self.connectSelf( "focus-out-event", self.onFocusOut )
         self.connectSelf( "destroy", self.onDestroy )
         self.connect( "released", self.onRelease )
         # Reload icons when the theme changed
@@ -181,6 +182,12 @@ class easyButton( Gtk.Button ):
     def connectSelf( self, event, callback ):
         self.connections.append( self.connect( event, callback ) )
 
+    def onFocusIn( self, widget, event ):
+        self.set_state_flags( Gtk.StateFlags.PRELIGHT, False )
+
+    def onFocusOut( self, widget, event ):
+        self.unset_state_flags( Gtk.StateFlags.PRELIGHT )
+
     def onRelease( self, widget ):
         widget.get_style_context().set_state( Gtk.StateFlags.NORMAL )
 
@@ -206,7 +213,11 @@ class easyButton( Gtk.Button ):
             label.set_attributes( labelStyle )
 
         label.set_ellipsize( Pango.EllipsizeMode.END )
-        label.set_alignment( 0.0, 1.0 )
+        if (Gtk.MAJOR_VERSION, Gtk.MINOR_VERSION) >= (3, 16):
+            label.set_xalign(0.0)
+            label.set_yalign(1.0)
+        else:
+            label.set_alignment( 0.0, 1.0 )
         label.set_max_width_chars(0)
         label.show()
         self.labelBox.pack_start( label , True, True, 0)
@@ -271,6 +282,7 @@ class ApplicationLauncher( easyButton ):
 
         self.desktopFile = desktopFile
         self.startupMonitorId = 0
+        self.relevance = 0
 
         self.loadDesktopEntry( desktopItem )
 
@@ -337,9 +349,11 @@ class ApplicationLauncher( easyButton ):
 
 
     def onFocusIn( self, widget, event ):
+        super(ApplicationLauncher, self).onFocusIn( widget, event )
         self.set_relief( Gtk.ReliefStyle.HALF )
 
     def onFocusOut( self, widget, event ):
+        super(ApplicationLauncher, self).onFocusOut( widget, event )
         self.set_relief( Gtk.ReliefStyle.NONE )
 
     def setupLabels( self ):
@@ -347,16 +361,34 @@ class ApplicationLauncher( easyButton ):
 
     def filterText( self, text ):
         keywords = text.lower().split()
+        self.relevance = 0
         appName = self.appName.lower()
         appGenericName = self.appGenericName.lower()
         appComment = self.appComment.lower()
         appExec = self.appExec.lower()
         for keyword in keywords:
             keyw = self.strip_accents(keyword)
+
+            # Hide if the term does not match
             if keyw != "" and appName.find( keyw ) == -1 and appGenericName.find( keyw ) == -1 and appComment.find( keyw ) == -1 and appExec.find( keyw ) == -1:
                 self.hide()
                 return False
 
+            # Give better ranking to the actual app name
+            if appName == keyw:
+                self.relevance += 32
+            elif appName.find( keyw ) == 0:
+                self.relevance += 16
+            elif appName.find( keyw ) != -1:
+                self.relevance += 8
+
+            if appExec.find( keyw ) != -1:
+                self.relevance += 4
+            if appComment.find( keyw ) != -1:
+                self.relevance += 2
+            if appGenericName.find( keyw ) != -1:
+                self.relevance += 1
+
         self.show()
         return True
 
